# Tutorials overview

This section contains a series of tutorials that will guide you through the process of modelling and simulating a production system using `prodsys`. The following tutorials are available:

## Basic Tutorials

- [Tutorial 1: Modelling and simulating a production system](tutorial_1_modelling_and_simulating_a_production_system.md)
- [Tutorial 2: Analyzing simulation results](tutorial_2_analyzing_simulation_results.md)
- [Tutorial 3: Optimizing a production system](tutorial_3_optimizing_a_production_system.md)
- [Tutorial 4: Optimizing production control](tutorial_4_optimizing_production_control.md)

## Advanced Tutorials

- [Tutorial 5: Advanced Dependencies](tutorial_5_advanced_dependencies.md) - Learn about ProcessDependency, ResourceDependency, AssemblyDependency, ToolDependency, and LotDependency
- [Tutorial 6: Orders and Schedules](tutorial_6_orders_and_schedules.md) - Explore order-based production and schedule-based production control
- [Tutorial 7: System Resources](tutorial_7_system_resources.md) - Model hierarchical production systems with SystemResource

All of the tutorials are also on the [github page of prodsys](https://github.com/sdm4fzi/prodsys) in the examples folder as jupyter notebooks available, so that you can run them yourself.

If you have any suggestions for new tutorials, please create an issue on [prodsys' github page](https://github.com/sdm4fzi/prodsys). For more information about the package's functionality, please see the [API reference](../API_reference/API_reference_0_overview.md).
